﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="ExtendedCustomerController.cs" company="Sitecore Corporation">
//   Copyright (c) Sitecore Corporation 1999-2016
// </copyright>
// <summary>
//   Extended customer controller class
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Sitecore.Commerce.DynamicsRetail.TransactionService
{
    using System.Globalization;
    using Microsoft.Dynamics.Commerce.Runtime.Client;
    using Microsoft.Dynamics.Retail.Ecommerce.Sdk.Core;
    using Microsoft.Dynamics.Retail.Ecommerce.Sdk.Core.Controllers;
    using CrtDataModel = Microsoft.Dynamics.Commerce.Runtime.DataModel;

    /// <summary>
    /// Extended customer controller class
    /// </summary>
    public class ExtendedCustomerController : CustomerController
    {
        /// <summary>
        /// Associate an existing customer to the current credentials if the criteria matches.
        /// </summary>
        /// <param name="email">The customer's e-mail address.</param>
        /// <param name="givenName">Name of the given.</param>
        /// <param name="surname">Name of the sur.</param>
        /// <param name="userId">The user identifier.</param>
        /// <returns>
        /// The customer's account number as string.
        /// </returns>
        /// <exception cref="Microsoft.Dynamics.Commerce.Runtime.DataValidationException">Thrown when the customer cannot be found.</exception>
        public override string AssociateCustomer(string email, string givenName, string surname, string userId)
        {
            var manager = CustomerManager.Create(CrtUtilities.GetCommerceRuntime());

            var dmCustomer = new CrtDataModel.Customer
            {
                Email = email,
                FirstName = givenName,
                LastName = surname,
                Language = CultureInfo.CurrentUICulture.ToString(),
            };

            dmCustomer = manager.CreateCustomer(dmCustomer);

            CreateUserCustomerMap(dmCustomer, userId);

            return dmCustomer.AccountNumber;
        }
    }
}