﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="IExtendedCheckoutService.cs" company="Sitecore Corporation">
//   Copyright (c) Sitecore Corporation 1999-2016
// </copyright>
// <summary>
//   The extended checkout service interface.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Sitecore.Commerce.DynamicsRetail.TransactionService
{
    using System.Collections.Generic;
    using System.ServiceModel;
    using Microsoft.Dynamics.Retail.Ecommerce.Sdk.Core.Models;
    using Microsoft.Dynamics.Retail.Ecommerce.Sdk.Services;

    /// <summary>
    /// Extended checkout service interface.
    /// </summary>
    [ServiceContract]
    public interface IExtendedCheckoutService
    {
        /// <summary>
        /// Updates the shipping address.
        /// </summary>
        /// <param name="cartId">The cart identifier.</param>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="shippingAddress">The shipping address.</param>
        /// <param name="dataLevel">The data level.</param>
        /// <returns>A sbopping cart</returns>
        [OperationContract]
        ShoppingCartResponse UpdateOrderShippingAddress(string cartId, string customerId, Address shippingAddress, ShoppingCartDataLevel dataLevel);

        /// <summary>
        /// Updates the shipping method.
        /// </summary>
        /// <param name="cartId">The cart identifier.</param>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="selectedDeliveryOption">The selected delivery option.</param>
        /// <param name="dataLevel">The data level.</param>
        /// <returns>A sbopping cart</returns>
        [OperationContract]
        ShoppingCartResponse UpdateOrderShippingMethod(string cartId, string customerId, SelectedDeliveryOption selectedDeliveryOption, ShoppingCartDataLevel dataLevel);

        /// <summary>
        /// Gets all delivery methods extended.
        /// </summary>
        /// <returns>A list of available delivery options</returns>
        [OperationContract]
        ExtendedDeliveryOptionsResponse GetDeliveryOptionsInfoExtended();
        
        /// <summary>
        /// Gets delivery preferences applicable to the current checkout cart.
        /// </summary>
        /// <param name="cartId">The cart identifier.</param>
        /// <returns>
        /// The delivery preference response object.
        /// </returns>
        [OperationContract]
        DeliveryPreferenceResponse GetDeliveryPreferencesExtended(string cartId);

        /// <summary>
        /// Gets the delivery methods extended.
        /// </summary>
        /// <param name="cartId">The cart identifier.</param>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="shipToAddress">The ship to address.</param>
        /// <returns>
        /// A list of delivery options
        /// </returns>
        [OperationContract]
        ExtendedDeliveryOptionsResponse GetOrderDeliveryOptionsForShippingExtended(string cartId, string customerId, Address shipToAddress);

        /// <summary>
        /// Gets the delivery methods per item extended.
        /// </summary>
        /// <param name="cartId">The cart identifier.</param>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="selectedLineShippingInfo">The selected line shipping information.</param>
        /// <returns>A list of delivery options</returns>
        [OperationContract]
        ExtendedDeliveryOptionsResponse GetLineDeliveryOptionsForShippingExtended(string cartId, string customerId, IEnumerable<SelectedLineShippingInfo> selectedLineShippingInfo);

        /// <summary>
        /// Sets the delivery method extended.
        /// </summary>
        /// <param name="cartId">The cart identifier.</param>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="selectedDeliveryOption">The selected delivery option.</param>
        /// <param name="dataLevel">The data level.</param>
        /// <returns>Set order's delivery option</returns>
        [OperationContract]
        ShoppingCartResponse SetOrderDeliveryOptionExtended(string cartId, string customerId, SelectedDeliveryOption selectedDeliveryOption, ShoppingCartDataLevel dataLevel);

        /// <summary>
        /// Sets the delivery method per item extended.
        /// </summary>
        /// <param name="cartId">The cart identifier.</param>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="selectedLineDeliveryOptions">The selected line delivery options.</param>
        /// <param name="dataLevel">The data level.</param>
        /// <returns>Set lines' delivery options</returns>
        [OperationContract]
        ShoppingCartResponse SetLineDeliveryOptionsExtended(string cartId, string customerId, IEnumerable<SelectedLineDeliveryOption> selectedLineDeliveryOptions, ShoppingCartDataLevel dataLevel);
        
        /// <summary>
        /// Creates the order extended.
        /// </summary>
        /// <param name="cartId">The cart identifier.</param>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="tenderDataLine">The tender data line.</param>
        /// <param name="emailAddress">The email address.</param>
        /// <returns>A sales order</returns>
        [OperationContract]
        ExtendedCreateSalesOrderResponse CreateOrderExtended(string cartId, string customerId, IEnumerable<TenderDataLine> tenderDataLine, string emailAddress);
    }
}
