﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="IExtendedCustomerService.cs" company="Sitecore Corporation">
//   Copyright (c) Sitecore Corporation 1999-2016
// </copyright>
// <summary>
//   The extended customer service interface.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Sitecore.Commerce.DynamicsRetail.TransactionService
{
    using System.Collections.Generic;
    using System.ServiceModel;
    using Microsoft.Dynamics.Retail.Ecommerce.Sdk.Services;
    using Microsoft.Dynamics.Retail.Ecommerce.Sdk.Core.Models;

    /// <summary>
    /// The extended customer service interface.
    /// </summary>
    [ServiceContract]
    public interface IExtendedCustomerService
    {
        /// <summary>
        /// Gets the customer.
        /// </summary>
        /// <param name="accountNumber">The customer account number.</param>
        /// <returns>
        /// A customer response.
        /// </returns>
        [OperationContract]
        CustomerResponse GetCustomerExtended(string accountNumber);

        /// <summary>
        /// Creates acustomer.
        /// </summary>
        /// <param name="email">The customer's e-mail address.</param>
        /// <param name="givenName">Name of the given.</param>
        /// <param name="surname">Name of the sur.</param>
        /// <param name="userId">The user identifier.</param>  
        /// <returns>
        /// A string response that contains the customer account number.
        /// </returns>
        [OperationContract]
        CreateUserResponse CreateCustomerExtended(string email, string givenName, string surname, string userId);

        /// <summary>
        /// Gets the customer addresses.
        /// </summary>
        /// <param name="accountNumber">The customer account number.</param>
        /// <returns>An address collection response.</returns>
        [OperationContract]
        AddressCollectionResponse GetAddressesExtended(string accountNumber);

        /// <summary>
        /// Updates the customer addresses.
        /// </summary>
        /// <param name="accountNumber">The customer account number.</param>
        /// <param name="addresses">The addresses.</param>
        /// <returns>Call success/failure response.</returns>
        [OperationContract]
        NullResponse UpdateAddressesExtended(string accountNumber, IEnumerable<Address> addresses);
    }
}
