﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="IExtendedShoppingCartService.cs" company="Sitecore Corporation">
//   Copyright (c) Sitecore Corporation 1999-2016
// </copyright>
// <summary>
//   The extended loyalty service interface.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Sitecore.Commerce.DynamicsRetail.TransactionService
{
    using System.ServiceModel;
    using Microsoft.Dynamics.Retail.Ecommerce.Sdk.Core.Models;
    using Microsoft.Dynamics.Retail.Ecommerce.Sdk.Services;
    
    /// <summary>
    /// The extended loyalty service interface.
    /// </summary>
    [ServiceContract]
    public interface IExtendedLoyaltyService
    {
        /// <summary>
        /// Generates the loyalty card identifier.
        /// </summary>
        /// <param name="cartId">The cart identifier.</param>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="dataLevel">The data level.</param>
        /// <returns>A shopping cart response</returns>
        [OperationContract]
        ShoppingCartResponse GenerateLoyaltyCardIdExtended(string cartId, string customerId, ShoppingCartDataLevel dataLevel);

        /// <summary>
        /// Gets the loyalty cards.
        /// </summary>
        /// <param name="customerId">The customer identifier.</param>
        /// <returns>A loyalty cards response</returns>
        [OperationContract]
        LoyaltyCardsResponse GetLoyaltyCardsExtended(string customerId);

        /// <summary>
        /// Gets the status of a loyalty card given it's id
        /// </summary> 
        /// <param name="loyaltyCardNumber">The loyalty card Id</param>
        /// <returns>A loyaltyCardResponse object</returns>
        [OperationContract]
        LoyaltyCardsResponse GetLoyaltyCardStatusExtended(string loyaltyCardNumber);

        /// <summary>
        /// Gets all loyalty cards status.
        /// </summary>
        /// <param name="customerId">The customer identifier.</param>
        /// <returns>A loyalty cards response</returns>
        [OperationContract]
        LoyaltyCardsResponse GetAllLoyaltyCardsStatusExtended(string customerId);

        /// <summary>
        /// Updates the loyalty card identifier.
        /// </summary>
        /// <param name="cartId">The cart identifier.</param>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="loyaltyCardId">The loyalty card identifier.</param>
        /// <param name="dataLevel">The data level.</param>
        /// <returns>A shopping cart response</returns>
        [OperationContract]
        ShoppingCartResponse UpdateLoyaltyCardIdExtended(string cartId, string customerId, string loyaltyCardId, ShoppingCartDataLevel dataLevel);
    }
}
