﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="IExtendedOrderService.cs" company="Sitecore Corporation">
//   Copyright (c) Sitecore Corporation 1999-2016
// </copyright>
// <summary>
//   The extended order service interface.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Sitecore.Commerce.DynamicsRetail.TransactionService
{
    using Microsoft.Dynamics.Retail.Ecommerce.Sdk.Services;
    using System.ServiceModel;

    /// <summary>
    /// The extended order service interface.
    /// </summary>
    [ServiceContract]
    public interface IExtendedOrderService
    {
        /// <summary>
        /// Gets the sales orders by customer.
        /// </summary>
        /// <param name="accountNumber">The account number.</param>
        /// <param name="includeSalesLines">if set to <c>true</c> [include sales lines].</param>
        /// <returns>
        /// The service response containing the sales order collection for the given customer.
        /// </returns>
        [OperationContract]
        SalesOrderCollectionResponse GetSalesOrdersByCustomerExtended(string accountNumber, bool includeSalesLines);

        /// <summary>
        /// Gets the committed sales order.
        /// </summary>
        /// <param name="salesId">The sales identifier.</param>
        /// <param name="includeSalesLines">if set to <c>true</c> [include sales lines].</param>
        /// <returns>
        /// The service response containing the commited sales order.
        /// </returns>
        [OperationContract]
        SalesOrderResponse GetCommittedSalesOrderExtended(string salesId, bool includeSalesLines);

        /// <summary>
        /// Gets the committed sales order by confirmation identifier.
        /// </summary>
        /// <param name="confirmationId">The confirmation identifier.</param>
        /// <param name="includeSalesLines">if set to <c>true</c> [include sales lines].</param>
        /// <returns>
        /// The service response containing the commited sales order.
        /// </returns>
        [OperationContract]
        SalesOrderResponse GetCommittedSalesOrderByConfirmationIdExtended(string confirmationId, bool includeSalesLines);

        /// <summary>
        /// Gets the pending sales order.
        /// </summary>
        /// <param name="transactionId">The transaction identifier.</param>
        /// <param name="includeSalesLines">if set to <c>true</c> [include sales lines].</param>
        /// <returns>
        /// The service response containing the pending sales order.
        /// </returns>
        [OperationContract]
        SalesOrderResponse GetPendingSalesOrderExtended(string transactionId, bool includeSalesLines);
    }
}
