﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="IExtendedPricingService.cs" company="Sitecore Corporation">
//   Copyright (c) Sitecore Corporation 1999-2016
// </copyright>
// <summary>
//   The extended pricing service interface.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Sitecore.Commerce.DynamicsRetail.TransactionService
{
    using System;
    using System.Collections.Generic;
    using System.ServiceModel;
    using Microsoft.Dynamics.Retail.Ecommerce.Sdk.Services;

    /// <summary>
    /// Extended pricing service interface.
    /// </summary>
    [ServiceContract]
    public interface IExtendedPricingService
    {
        /// <summary>
        /// Gets the active listing price filtered.
        /// </summary>
        /// <param name="listingIds">The listing ids.</param>
        /// <returns>Response containing active listing prices but only for the specific ids</returns>
        [OperationContract]
        ListingPriceResponse GetActiveListingPriceFiltered(IEnumerable<long> listingIds);

        /// <summary>
        /// Gets the listing price.
        /// </summary>
        /// <param name="listingIds">The listing ids.</param>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="date">The date.</param>
        /// <returns>
        /// Response containing listing prices based on customer and/or date
        /// </returns>
        [OperationContract]
        ListingPriceResponse GetActiveListingPriceExtended(IEnumerable<long> listingIds, string customerId, DateTime? date);

        /// <summary>
        /// Gets the listing price per catalog.
        /// </summary>
        /// <param name="listingIds">The listing ids.</param>
        /// <param name="channelId">The channel identifier.</param>
        /// <param name="catalogId">The catalog identifier.</param>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="date">The date.</param>
        /// <returns>Response containing listing prices per catalog based on customer and/or date</returns>
        [OperationContract]
        ListingPriceResponse GetActiveListingPricePerCatalogExtended(IEnumerable<long> listingIds, long channelId, long catalogId, string customerId, DateTime? date);

        /// <summary>
        /// Gets the listing price with affiliations applied.
        /// </summary>
        /// <param name="listingIds">The listing ids.</param>
        /// <param name="affiliationLoyaltyTierIds">The affiliation loyalty tier ids.</param>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="date">The date.</param>
        /// <returns>Response containing listing prices with affiliations applied based on customer and/or date</returns>
        [OperationContract]
        ListingPriceResponse GetActiveListingPriceWithAffiliationsAppliedExtended(IEnumerable<long> listingIds, IEnumerable<long> affiliationLoyaltyTierIds, string customerId, DateTime? date);

        /// <summary>
        /// Gets the listing price per catalog with affiliations applied.
        /// </summary>
        /// <param name="listingIds">The listing ids.</param>
        /// <param name="channelId">The channel identifier.</param>
        /// <param name="catalogId">The catalog identifier.</param>
        /// <param name="affiliationLoyaltyTierIds">The affiliation loyalty tier ids.</param>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="date">The date.</param>
        /// <returns>Response containing listing prices per catalog and with affiliations applied based on customer and/or date</returns>
        [OperationContract]
        ListingPriceResponse GetActiveListingPricePerCatalogWithAffiliationsAppliedExtended(IEnumerable<long> listingIds, long channelId, long catalogId, IEnumerable<long> affiliationLoyaltyTierIds, string customerId, DateTime? date);
    }
}
