﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="IExtendedWishListService.cs" company="Sitecore Corporation">
//   Copyright (c) Sitecore Corporation 1999-2016
// </copyright>
// <summary>
//   The extended wish list service interface.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Sitecore.Commerce.DynamicsRetail.TransactionService
{
    using System.ServiceModel;
    using System.Collections.Generic;
    using Microsoft.Dynamics.Retail.Ecommerce.Sdk.Core.Models;
    using Microsoft.Dynamics.Retail.Ecommerce.Sdk.Services;

    /// <summary>
    /// The extended wish list service interface.
    /// </summary>
    [ServiceContract]
    public interface IExtendedWishListService
    {
        /// <summary>
        /// Adds the items to wish list.
        /// </summary>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="wishListId">The wish list identifier.</param>
        /// <param name="listings">The listings.</param>
        /// <returns>A wish list response</returns>
        [OperationContract]
        WishListResponse AddItemsToWishListExtended(string customerId, string wishListId, IEnumerable<Listing> listings);

        /// <summary>
        /// Creates the wish list.
        /// </summary>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="wishListName">Name of the wish list.</param>
        /// <returns>A wish list response</returns>
        [OperationContract]
        WishListResponse CreateWishListExtended(string customerId, string wishListName);

        /// <summary>
        /// Gets the wish list.
        /// </summary>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="wishListId">The wish list identifier.</param>
        /// <returns>A wish list response</returns>
        [OperationContract]
        WishListResponse GetWishListExtended(string customerId, string wishListId);

        /// <summary>
        /// Gets the wish lists for current customer.
        /// </summary>
        /// <param name="customerId">The customer identifier.</param>
        /// <returns>A wish list collection response</returns>
        [OperationContract]
        WishListCollectionResponse GetWishListsForCurrentCustomerExtended(string customerId);

        /// <summary>
        /// Removes the item from wish list.
        /// </summary>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="wishListId">The wish list identifier.</param>
        /// <param name="listingId">The listing identifier.</param>
        /// <returns>A null response</returns>
        [OperationContract]
        NullResponse RemoveItemFromWishListExtended(string customerId, string wishListId, string listingId);

        /// <summary>
        /// Updates the items on wish list.
        /// </summary>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="wishListId">The wish list identifier.</param>
        /// <param name="listings">The listings.</param>
        /// <returns>A wish list response</returns>
        [OperationContract]
        WishListResponse UpdateItemsOnWishListExtended(string customerId, string wishListId, IEnumerable<Listing> listings);

        /// <summary>
        /// Updates the wish list properties.
        /// </summary>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="wishListId">The wish list identifier.</param>
        /// <param name="wishListName">Name of the wish list.</param>
        /// <param name="isFavorite">The is favorite.</param>
        /// <returns>A wish list response</returns>
        [OperationContract]
        WishListResponse UpdateWishListPropertiesExtended(string customerId, string wishListId, string wishListName, bool? isFavorite);

        /// <summary>
        /// Deletes the wish list.
        /// </summary>
        /// <param name="customerId">The customer identifier.</param>
        /// <param name="wishListId">The wish list identifier.</param>
        /// <returns>
        /// A wish list response
        /// </returns>
        [OperationContract]
        NullResponse DeleteWishListExtended(string customerId, string wishListId);
    }
}
