﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="ExtendedAddressMapper.cs" company="Sitecore Corporation">
//   Copyright (c) Sitecore Corporation 1999-2016
// </copyright>
// <summary>
//   Extended address mapper class
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Sitecore.Commerce.DynamicsRetail.TransactionService
{
    using Microsoft.Dynamics.Retail.Ecommerce.Sdk.Core.Models;
    using CrtDataModel = Microsoft.Dynamics.Commerce.Runtime.DataModel;

    /// <summary>
    /// Extended address mapper class
    /// </summary>
    public static class ExtendedAddressMapper
    {
        /// <summary>
        /// Convert the Data Model Address to a View Model Address.
        /// </summary>
        /// <param name="address">The data model address</param>
        /// <returns>Address</returns>
        public static Address ConvertToViewModel(CrtDataModel.Address address)
        {
            if (address == null)
            {
                return null;
            }

            var vmAddress = new Address
            {
                StreetNumber = address.StreetNumber,
                Street = address.Street,
                City = address.City,
                State = address.State,
                County = address.County,
                DistrictName = address.DistrictName,
                ZipCode = address.ZipCode,
                Country = address.ThreeLetterISORegionName,
                Email = address.Email,
                EmailContent = address.EmailContent,
                Phone = address.Phone,
                AttentionTo = address.AttentionTo,
                AddressType = (AddressType)address.AddressTypeValue,
                RecordId = address.RecordId,
                AddressFriendlyName = address.Name,
                IsPrimary = address.IsPrimary,
                Name = address.Name,
            };

            return vmAddress;
        }

        /// <summary>
        /// Converts Address view model to CRT Address.
        /// </summary>
        /// <param name="address">The view model address.</param>
        /// <returns>
        /// The CRT address.
        /// </returns>
        public static CrtDataModel.Address ConvertToDataModel(Address address)
        {
            if (address == null)
            {
                return null;
            }

            return new CrtDataModel.Address
            {
                StreetNumber = address.StreetNumber,
                Street = address.Street,
                City = address.City,
                State = address.State,
                County = address.County,
                DistrictName = address.DistrictName,
                ZipCode = address.ZipCode,
                ThreeLetterISORegionName = address.Country,
                Email = address.Email,
                EmailContent = address.EmailContent,
                Phone = address.Phone,
                AttentionTo = address.AttentionTo,
                AddressTypeValue = (int)address.AddressType,
                Name = address.Name,
                IsPrimary = address.IsPrimary
            };
        }
    }
}